@@ -1,4 +1,4 @@
-#!/usr/local/bin/python2.5
+#!/usr/local/bin/python2.7
 #
 # This program demonstrates how to use GConf.  The key thing is that
 # the main window and the prefs dialog have NO KNOWLEDGE of one
@@ -40,9 +40,9 @@
 # Special mention of an idiom often used in GTK+ apps that does
 # not work right with GConf but may appear to at first:
 #
-# i_am_changing_value = gtk.TRUE
+# i_am_changing_value = True
 # change_value (value)
-# i_am_changing_value = gtk.FALSE
+# i_am_changing_value = False
 # 
 # This breaks for several reasons: notification of changes
 # may be asynchronous, you may get notifications that are not
@@ -90,7 +90,7 @@ def main ():
 
 # Quit app when window is destroyed 
 def destroy_callback (widget, *data):
-    gtk.mainquit ()
+    gtk.main_quit ()
 
     
 # Remove the notification callback when the widget monitoring
@@ -174,28 +174,28 @@ def create_main_window (client):
     w = gtk.Window ()
     w.set_title ('basic-gconf-app Main Window')
   
-    vbox = gtk.VBox (gtk.FALSE, 5)
+    vbox = gtk.VBox (False, 5)
     vbox.set_border_width (5)
     w.add (vbox)
   
     # Create labels that we can "configure"
     config = create_configurable_widget (client, "/apps/basic-gconf-app/foo")
-    vbox.pack_start (config, gtk.TRUE, gtk.TRUE)
+    vbox.pack_start (config, True, True)
 
     config = create_configurable_widget (client, "/apps/basic-gconf-app/bar")
-    vbox.pack_start (config, gtk.TRUE, gtk.TRUE)
+    vbox.pack_start (config, True, True)
   
     config = create_configurable_widget (client, "/apps/basic-gconf-app/baz")
-    vbox.pack_start (config, gtk.TRUE, gtk.TRUE)
+    vbox.pack_start (config, True, True)
 
     config = create_configurable_widget (client, "/apps/basic-gconf-app/blah");
-    vbox.pack_start (config, gtk.TRUE, gtk.TRUE)
+    vbox.pack_start (config, True, True)
 
     w.connect ('destroy', destroy_callback)
     w.set_data ('client', client)
   
     prefs = gtk.Button ("Prefs");
-    vbox.pack_end ( prefs, gtk.FALSE, gtk.FALSE)
+    vbox.pack_end ( prefs, False, False)
     prefs.connect ('clicked', prefs_clicked, w)
     
     return w
@@ -231,13 +231,13 @@ def config_entry_commit (entry, *args):
 	client.unset (key)
 	
 # Create an entry used to edit the given config key 
-def create_config_entry (prefs_dialog, client, config_key, focus=gtk.FALSE):
-    hbox = gtk.HBox (gtk.FALSE, 5)
+def create_config_entry (prefs_dialog, client, config_key, focus=False):
+    hbox = gtk.HBox (False, 5)
     label = gtk.Label (config_key)
     entry = gtk.Entry ()
 
-    hbox.pack_start (label, gtk.FALSE, gtk.FALSE, 0)
-    hbox.pack_end (entry, gtk.FALSE, gtk.FALSE, 0)
+    hbox.pack_start (label, False, False, 0)
+    hbox.pack_end (entry, False, False, 0)
 
     # this will print an error via default error handler
     # if the key isn't set to a string
@@ -279,24 +279,24 @@ def create_prefs_dialog (parent, client):
     dialog.set_default_response (gtk.RESPONSE_ACCEPT)
 
     # resizing doesn't grow the entries anyhow
-    dialog.set_resizable (gtk.FALSE)
+    dialog.set_resizable (False)
   
-    vbox = gtk.VBox (gtk.FALSE, 5)
+    vbox = gtk.VBox (False, 5)
     vbox.set_border_width (5)
   
     dialog.vbox.pack_start (vbox)
 
-    entry = create_config_entry (dialog, client, "/apps/basic-gconf-app/foo", gtk.TRUE)
-    vbox.pack_start (entry, gtk.FALSE, gtk.FALSE)
+    entry = create_config_entry (dialog, client, "/apps/basic-gconf-app/foo", True)
+    vbox.pack_start (entry, False, False)
 
     entry = create_config_entry (dialog, client, "/apps/basic-gconf-app/bar")
-    vbox.pack_start (entry, gtk.FALSE, gtk.FALSE)
+    vbox.pack_start (entry, False, False)
   
     entry = create_config_entry (dialog, client, "/apps/basic-gconf-app/baz")
-    vbox.pack_start (entry, gtk.FALSE, gtk.FALSE)
+    vbox.pack_start (entry, False, False)
 
     entry = create_config_entry (dialog, client, "/apps/basic-gconf-app/blah")
-    vbox.pack_start (entry, gtk.FALSE, gtk.FALSE)
+    vbox.pack_start (entry, False, False)
   
     return dialog
 
